@@ -47,7 +47,7 @@ Bitshuffle, CMS (color space transformations), and Float24
 
 :Author: `Christoph Gohlke <https://www.cgohlke.com>`_
 :License: BSD 3-Clause
-:Version: 2022.12.22
+:Version: 2022.12.24
 :DOI: 10.5281/zenodo.6915978
 
 Quickstart
@@ -148,9 +148,15 @@ Test requirements:
 Revisions
 ---------
 
+2022.12.24
+
+- Pass 6512 tests.
+- Fix PNG codec error handling.
+- Fix truncated transferfunctions in cms_profile (#57).
+- Fix exceptions not raised in cdef functions not returning Python object.
+
 2022.12.22
 
-- Pass 6510 tests.
 - Require libtiff 4.5 (breaking).
 - Require libavif 0.11 (breaking).
 - Change jpegxl_encode level parameter to resemble libjpeg quality (breaking).
@@ -283,7 +289,7 @@ This software includes `qoi.h <https://github.com/phoboslab/qoi/>`_.
 
 Wheels for macOS may not be available for the latest releases.
 
-Build instructions and wheels for manylinux and macOS courtesy of
+Build instructions for manylinux and macOS courtesy of
 `Grzegorz Bokota <https://github.com/Czaki/imagecodecs_build>`_.
 
 Update pip and setuptools to the latest version before installing imagecodecs::
@@ -450,7 +456,7 @@ View the image in the JP2 file from the command line::
 
 from __future__ import annotations
 
-__version__ = '2022.12.22'
+__version__ = '2022.12.24'
 
 import os
 import sys
@@ -497,7 +503,7 @@ _API = {
     'brotli': [],
     'brunsli': [],
     'bz2': [],
-    'cms': ['cms_transform', 'cms_profile'],
+    'cms': ['cms_transform', 'cms_profile', 'cms_profile_validate'],
     'deflate': ['deflate_crc32', 'deflate_adler32', ('deflate', 'gzip')],
     'gif': [],
     'heif': [],
@@ -535,7 +541,7 @@ _API = {
     'zlibng': ['zlibng_crc32', 'zlibng_adler32'],
     'zopfli': [],
     'zstd': [],
-    # 'module': ['attribute1', 'attribute2', ('codec1', 'code2')]
+    # 'module': ['attribute1', 'attribute2', ('codec1', 'codec2')]
 }
 
 # map extra to existing attributes
